summaryrefslogtreecommitdiffstats
path: root/kig/objects
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:55:10 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:55:10 -0600
commit746abe84406ed1ec1a8dc68f29ce0ab8322ccc80 (patch)
tree34a73ef7b8771de54099eeffb941117e49a8865e /kig/objects
parent999f961ff5278b84c8ffd8a91addb9343e589cf0 (diff)
downloadtdeedu-746abe84406ed1ec1a8dc68f29ce0ab8322ccc80.tar.gz
tdeedu-746abe84406ed1ec1a8dc68f29ce0ab8322ccc80.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kig/objects')
-rw-r--r--kig/objects/bogus_imp.cc8
-rw-r--r--kig/objects/circle_imp.cc16
-rw-r--r--kig/objects/conic_imp.cc20
-rw-r--r--kig/objects/cubic_imp.cc20
-rw-r--r--kig/objects/line_imp.cc4
-rw-r--r--kig/objects/object_calcer.cc12
-rw-r--r--kig/objects/object_calcer.h6
-rw-r--r--kig/objects/object_factory.cc6
-rw-r--r--kig/objects/object_holder.cc2
-rw-r--r--kig/objects/object_imp.h2
-rw-r--r--kig/objects/object_imp_factory.cc4
-rw-r--r--kig/objects/point_imp.cc2
12 files changed, 51 insertions, 51 deletions
diff --git a/kig/objects/bogus_imp.cc b/kig/objects/bogus_imp.cc
index 5c68c30c..b7b8f41e 100644
--- a/kig/objects/bogus_imp.cc
+++ b/kig/objects/bogus_imp.cc
@@ -88,22 +88,22 @@ InvalidImp::InvalidImp()
void InvalidImp::fillInNextEscape( TQString& s, const KigDocument& ) const
{
- s = s.tqarg( "[invalid]" );
+ s = s.arg( "[invalid]" );
}
void DoubleImp::fillInNextEscape( TQString& s, const KigDocument& ) const
{
- s = s.tqarg( mdata );
+ s = s.arg( mdata );
}
void IntImp::fillInNextEscape( TQString& s, const KigDocument& ) const
{
- s = s.tqarg( mdata );
+ s = s.arg( mdata );
}
void StringImp::fillInNextEscape( TQString& s, const KigDocument& ) const
{
- s = s.tqarg( mdata );
+ s = s.arg( mdata );
}
HierarchyImp::HierarchyImp( const ObjectHierarchy& h )
diff --git a/kig/objects/circle_imp.cc b/kig/objects/circle_imp.cc
index 4b6c1123..38522c22 100644
--- a/kig/objects/circle_imp.cc
+++ b/kig/objects/circle_imp.cc
@@ -235,8 +235,8 @@ TQString CircleImp::polarEquationString( const KigDocument& w ) const
{
TQString ret = i18n( "rho = %1 [centered at %2]" );
ConicPolarData data = polarData();
- ret = ret.tqarg( data.pdimen, 0, 'g', 3 );
- ret = ret.tqarg( w.coordinateSystem().fromScreen( data.focus1, w ) );
+ ret = ret.arg( data.pdimen, 0, 'g', 3 );
+ ret = ret.arg( w.coordinateSystem().fromScreen( data.focus1, w ) );
return ret;
}
@@ -244,18 +244,18 @@ TQString CircleImp::cartesianEquationString( const KigDocument& ) const
{
TQString ret = i18n( "x² + y² + %1 x + %2 y + %3 = 0" );
ConicCartesianData data = cartesianData();
- ret = ret.tqarg( data.coeffs[3], 0, 'g', 3 );
- ret = ret.tqarg( data.coeffs[4], 0, 'g', 3 );
- ret = ret.tqarg( data.coeffs[5], 0, 'g', 3 );
+ ret = ret.arg( data.coeffs[3], 0, 'g', 3 );
+ ret = ret.arg( data.coeffs[4], 0, 'g', 3 );
+ ret = ret.arg( data.coeffs[5], 0, 'g', 3 );
return ret;
}
TQString CircleImp::simplyCartesianEquationString( const KigDocument& ) const
{
TQString ret = i18n( "( x - %1 )² + ( y - %2 )² = %3" );
- ret = ret.tqarg( mcenter.x, 0, 'g', 3 );
- ret = ret.tqarg( mcenter.y, 0, 'g', 3 );
- ret = ret.tqarg( mradius * mradius, 0, 'g', 3 );
+ ret = ret.arg( mcenter.x, 0, 'g', 3 );
+ ret = ret.arg( mcenter.y, 0, 'g', 3 );
+ ret = ret.arg( mradius * mradius, 0, 'g', 3 );
return ret;
}
diff --git a/kig/objects/conic_imp.cc b/kig/objects/conic_imp.cc
index 5828fc98..81331522 100644
--- a/kig/objects/conic_imp.cc
+++ b/kig/objects/conic_imp.cc
@@ -204,12 +204,12 @@ TQString ConicImp::cartesianEquationString( const KigDocument& ) const
{
TQString ret = i18n( "%1 x² + %2 y² + %3 xy + %4 x + %5 y + %6 = 0" );
ConicCartesianData data = cartesianData();
- ret = ret.tqarg( data.coeffs[0], 0, 'g', 3 );
- ret = ret.tqarg( data.coeffs[1], 0, 'g', 3 );
- ret = ret.tqarg( data.coeffs[2], 0, 'g', 3 );
- ret = ret.tqarg( data.coeffs[3], 0, 'g', 3 );
- ret = ret.tqarg( data.coeffs[4], 0, 'g', 3 );
- ret = ret.tqarg( data.coeffs[5], 0, 'g', 3 );
+ ret = ret.arg( data.coeffs[0], 0, 'g', 3 );
+ ret = ret.arg( data.coeffs[1], 0, 'g', 3 );
+ ret = ret.arg( data.coeffs[2], 0, 'g', 3 );
+ ret = ret.arg( data.coeffs[3], 0, 'g', 3 );
+ ret = ret.arg( data.coeffs[4], 0, 'g', 3 );
+ ret = ret.arg( data.coeffs[5], 0, 'g', 3 );
return ret;
}
@@ -218,11 +218,11 @@ TQString ConicImp::polarEquationString( const KigDocument& w ) const
TQString ret = i18n( "rho = %1/(1 + %2 cos theta + %3 sin theta)\n [centered at %4]" );
const ConicPolarData data = polarData();
- ret = ret.tqarg( data.pdimen, 0, 'g', 3 );
- ret = ret.tqarg( -data.ecostheta0, 0, 'g', 3 );
- ret = ret.tqarg( -data.esintheta0, 0, 'g', 3 );
+ ret = ret.arg( data.pdimen, 0, 'g', 3 );
+ ret = ret.arg( -data.ecostheta0, 0, 'g', 3 );
+ ret = ret.arg( -data.esintheta0, 0, 'g', 3 );
- ret = ret.tqarg( w.coordinateSystem().fromScreen( data.focus1, w ) );
+ ret = ret.arg( w.coordinateSystem().fromScreen( data.focus1, w ) );
return ret;
}
diff --git a/kig/objects/cubic_imp.cc b/kig/objects/cubic_imp.cc
index b4a85b8e..9fc8c53c 100644
--- a/kig/objects/cubic_imp.cc
+++ b/kig/objects/cubic_imp.cc
@@ -417,18 +417,18 @@ TQString CubicImp::cartesianEquationString( const KigDocument& ) const
*/
TQString ret = i18n( "%6 x³ + %9 y³ + %7 x²y + %8 xy² + %5 y² + %3 x² + %4 xy + %1 x + %2 y" );
- ret = ret.tqarg( mdata.coeffs[1], 0, 'g', 3 );
- ret = ret.tqarg( mdata.coeffs[2], 0, 'g', 3 );
- ret = ret.tqarg( mdata.coeffs[3], 0, 'g', 3 );
- ret = ret.tqarg( mdata.coeffs[4], 0, 'g', 3 );
- ret = ret.tqarg( mdata.coeffs[5], 0, 'g', 3 );
- ret = ret.tqarg( mdata.coeffs[6], 0, 'g', 3 );
- ret = ret.tqarg( mdata.coeffs[7], 0, 'g', 3 );
- ret = ret.tqarg( mdata.coeffs[8], 0, 'g', 3 );
- ret = ret.tqarg( mdata.coeffs[9], 0, 'g', 3 );
+ ret = ret.arg( mdata.coeffs[1], 0, 'g', 3 );
+ ret = ret.arg( mdata.coeffs[2], 0, 'g', 3 );
+ ret = ret.arg( mdata.coeffs[3], 0, 'g', 3 );
+ ret = ret.arg( mdata.coeffs[4], 0, 'g', 3 );
+ ret = ret.arg( mdata.coeffs[5], 0, 'g', 3 );
+ ret = ret.arg( mdata.coeffs[6], 0, 'g', 3 );
+ ret = ret.arg( mdata.coeffs[7], 0, 'g', 3 );
+ ret = ret.arg( mdata.coeffs[8], 0, 'g', 3 );
+ ret = ret.arg( mdata.coeffs[9], 0, 'g', 3 );
ret.append( i18n( " + %1 = 0" ) );
- ret = ret.tqarg( mdata.coeffs[0], 0, 'g', 3 );
+ ret = ret.arg( mdata.coeffs[0], 0, 'g', 3 );
// we should find a common place to do this...
ret.replace( "+ -", "- " );
diff --git a/kig/objects/line_imp.cc b/kig/objects/line_imp.cc
index 7583dc71..a49078a1 100644
--- a/kig/objects/line_imp.cc
+++ b/kig/objects/line_imp.cc
@@ -186,8 +186,8 @@ const TQString AbstractLineImp::equationString() const
TQString::fromUtf8( r > 0 ? "+" : "-" ) +
TQString::fromUtf8( " %2" );
- ret = ret.tqarg( m, 0, 'g', 3 );
- ret = ret.tqarg( abs( r ), 0, 'g', 3 );
+ ret = ret.arg( m, 0, 'g', 3 );
+ ret = ret.arg( abs( r ), 0, 'g', 3 );
return ret;
}
diff --git a/kig/objects/object_calcer.cc b/kig/objects/object_calcer.cc
index 0bf4e774..40545ed1 100644
--- a/kig/objects/object_calcer.cc
+++ b/kig/objects/object_calcer.cc
@@ -106,16 +106,16 @@ std::vector<ObjectCalcer*> ObjectTypeCalcer::parents() const
void ObjectCalcer::addChild( ObjectCalcer* c )
{
- mtqchildren.push_back( c );
+ mchildren.push_back( c );
ref();
}
void ObjectCalcer::delChild( ObjectCalcer* c )
{
- std::vector<ObjectCalcer*>::iterator i = std::find( mtqchildren.begin(), mtqchildren.end(), c );
- assert( i != mtqchildren.end() );
+ std::vector<ObjectCalcer*>::iterator i = std::find( mchildren.begin(), mchildren.end(), c );
+ assert( i != mchildren.end() );
- mtqchildren.erase( i );
+ mchildren.erase( i );
deref();
}
@@ -175,9 +175,9 @@ ObjectImp* ObjectConstCalcer::switchImp( ObjectImp* newimp )
return ret;
}
-std::vector<ObjectCalcer*> ObjectCalcer::tqchildren() const
+std::vector<ObjectCalcer*> ObjectCalcer::children() const
{
- return mtqchildren;
+ return mchildren;
}
const ObjectImpType* ObjectPropertyCalcer::impRequirement(
diff --git a/kig/objects/object_factory.cc b/kig/objects/object_factory.cc
index 942139f4..f2957a7e 100644
--- a/kig/objects/object_factory.cc
+++ b/kig/objects/object_factory.cc
@@ -299,12 +299,12 @@ void ObjectFactory::redefinePoint(
std::mem_fun( calcmeth ) );
ObjectCalcer* v = 0;
- // we don't want one of our tqchildren as a parent...
- std::set<ObjectCalcer*> tqchildren = getAllChildren( point );
+ // we don't want one of our children as a parent...
+ std::set<ObjectCalcer*> children = getAllChildren( point );
for ( std::vector<ObjectCalcer*>::iterator i = os.begin();
i != os.end(); ++i )
if ( (*i)->imp()->inherits( CurveImp::stype() ) &&
- tqchildren.find( *i ) == tqchildren.end() )
+ children.find( *i ) == children.end() )
{
v = *i;
break;
diff --git a/kig/objects/object_holder.cc b/kig/objects/object_holder.cc
index b6c5f09e..cdf06396 100644
--- a/kig/objects/object_holder.cc
+++ b/kig/objects/object_holder.cc
@@ -160,5 +160,5 @@ TQString ObjectHolder::selectStatement() const
if ( n.isEmpty() )
return i18n( imp()->type()->selectStatement() );
else
- return i18n( imp()->type()->selectNameStatement() ).tqarg( n );
+ return i18n( imp()->type()->selectNameStatement() ).arg( n );
}
diff --git a/kig/objects/object_imp.h b/kig/objects/object_imp.h
index ddf0eb46..eaf29328 100644
--- a/kig/objects/object_imp.h
+++ b/kig/objects/object_imp.h
@@ -170,7 +170,7 @@ public:
* Returns a translatable string of the form "Select point %1". %1
* will be filled in by whomever calls this function with the name
* of the object in question. This function should be used as
- * follows: i18n( x->selectNameStatement() ).tqarg( xname ).
+ * follows: i18n( x->selectNameStatement() ).arg( xname ).
*/
const char* selectNameStatement() const;
diff --git a/kig/objects/object_imp_factory.cc b/kig/objects/object_imp_factory.cc
index 1d466835..d095c238 100644
--- a/kig/objects/object_imp_factory.cc
+++ b/kig/objects/object_imp_factory.cc
@@ -291,7 +291,7 @@ ObjectImp* ObjectImpFactory::deserialize( const TQString& type,
#define KIG_GENERIC_PARSE_ERROR \
{ \
error = i18n( "An error was encountered at line %1 in file %2." ) \
- .tqarg( __LINE__ ).tqarg( __FILE__ ); \
+ .arg( __LINE__ ).arg( __FILE__ ); \
return 0; \
}
@@ -504,7 +504,7 @@ ObjectImp* ObjectImpFactory::deserialize( const TQString& type,
"which this Kig version does not support."
"Perhaps you have compiled Kig without support "
"for this object type,"
- "or perhaps you are using an older Kig version." ).tqarg( type );
+ "or perhaps you are using an older Kig version." ).arg( type );
return 0;
}
diff --git a/kig/objects/point_imp.cc b/kig/objects/point_imp.cc
index 1e5b8766..539f98b3 100644
--- a/kig/objects/point_imp.cc
+++ b/kig/objects/point_imp.cc
@@ -137,7 +137,7 @@ void PointImp::setCoordinate( const Coordinate& c )
void PointImp::fillInNextEscape( TQString& s, const KigDocument& doc ) const
{
- s = s.tqarg( doc.coordinateSystem().fromScreen( mc, doc ) );
+ s = s.arg( doc.coordinateSystem().fromScreen( mc, doc ) );
}
void PointImp::visit( ObjectImpVisitor* vtor ) const
diff --git a/kig/objects/object_calcer.h b/kig/objects/object_calcer.h
index 98262e5e..6df94fe8 100644
--- a/kig/objects/object_calcer.h
+++ b/kig/objects/object_calcer.h
@@ -77,10 +77,10 @@ protected:
void ref();
void deref();
// we keep track of our tqchildren, so algorithms can easily walk over
// the dependency graph..
- std::vector<ObjectCalcer*> mtqchildren;
+ std::vector<ObjectCalcer*> mchildren;
ObjectCalcer();
public:
@@ -102,7 +102,7 @@ public:
/**
* Returns the child ObjectCalcer's of this ObjectCalcer.
*/
- std::vector<ObjectCalcer*> tqchildren() const;
+ std::vector<ObjectCalcer*> children() const;
virtual ~ObjectCalcer();
/**
@@ -77,10 +77,10 @@ protected:
void ref();
void deref();
- // we keep track of our tqchildren, so algorithms can easily walk over
+ // we keep track of our children, so algorithms can easily walk over
// the dependency graph..